<?php

namespace DMG\Newsletters;

/**
 * Class Post_Type
 *
 * Register the new post type to support newsletter signups.
 *
 * @package DMG\Newsletters
 */
class Post_Type {

	/**
	 * Post type name
	 * 
	 * @var string
	 */
	const NAME = 'dmg_newsletter';

	/**
	 * Init.
	 * 
	 * @return void
	 */
	public static function init(): void {
		add_action( 'init', array( __CLASS__, 'register' ) );
		add_action( 'enqueue_block_editor_assets', array( __CLASS__, 'enqueue_block_editor_assets' ) );
	}

	/**
	 * Register the post type.
	 * 
	 * @return void
	 */
	public static function register(): void {
		register_post_type(
			self::NAME,
			array(
				'label'        => 'Newsletters',
				'labels'       => array(
					'singular_name' => 'Newsletter',
					'add_new'       => 'Add New Newsletter',
					'edit_item'     => 'Edit Newsletter',
				),
				'description'  => 'Post type for managing individual newsletter subscriptions.',
				'public'       => true,
				'menu_icon'    => 'dashicons-email-alt',
				'show_in_rest' => true,
				'has_archive'  => true,
				'rewrite'      => array(
					'slug' => 'newsletters',
				),
				'supports'     => array(
					'title',
					'editor',
					'excerpt',
					'thumbnail',
					'custom-fields',
					'page-attributes'
				),
				'taxonomies'   => array(
					'category',
					'post_tag'
				),
			)
		);
	}

	/**
	 * Enqueue block editor assets.
	 * 
	 * @return void
	 */
	public static function enqueue_block_editor_assets(): void {

		// Post type check.
		if ( self::NAME !== get_post_type() ) {
			return;
		}

		// Add button for converting to post
		$asset = require_once( dirname( __FILE__ ) . '/build/editor.asset.php' );

		wp_enqueue_script(
			'dmg-newsletters-editor',
			plugin_dir_url( __FILE__ ) . 'build/editor.js',
			$asset['dependencies'],
			$asset['version'],
			array(
				'in_footer' => true
			)
		);
	}

}

Post_Type::init();
